import json, sys

FIELDS_FROM_START = [
    "authors",
    "difficulty",
    "forwardPrefabs",
    "reversePrefabs",
    "rollingStartPosition",
    "classification",
    "prefabs",
    "description",
    "name",
    "defaultLaps",
    "date",
    "startNode",
]

FIELDS_FROM_END = [
    "reverseStartPosition",
]

def find_node(nodes, id):
    for node in nodes:
        if node["oldId"] == id:
            return node
    return None

def main(args):
    races = []
    for path in args:
        with open(path, 'r') as f:
            races.append(json.loads(f.read()))

    output = {}

    for field in FIELDS_FROM_START:
        output[field] = races[0][field]

    for field in FIELDS_FROM_END:
        output[field] = races[-1][field]

    # Set start positions
    start = find_node(races[0]["startPositions"], races[0]["defaultStartPosition"])
    end = find_node(races[-1]["startPositions"], races[-1]["reverseStartPosition"])

    start["oldId"] = 1
    end["oldId"] = 2

    output["startPositions"] = [start, end]

    output["defaultStartPosition"] = start["oldId"]
    output["reverseStartPosition"] = end["oldId"]

    # Combine nodes/segments
    id_offset = 0
    nodes = []
    segments = []
    last_end_node = None

    for race in races:
        print(id_offset, last_end_node, file=sys.stderr)
        if last_end_node is not None:
            segment_id = id_offset
            id_offset += 1

            segments.append({
                "to": race["startNode"] + id_offset,
                "mode": "waypoint",
                "oldId": segment_id,
                "capsules": {},
                "from": last_end_node,
                "name": f"Inter-Segment {segment_id}",
            })
        last_end_node = race["endNode"] + id_offset

        max_id = 0
        for node in race["pathnodes"]:
            if node["oldId"] > max_id:
                max_id = node["oldId"]

            node["oldId"] += id_offset
            node["name"] = f"Pathnode {node['oldId']}"
            nodes.append(node)

        for segment in race["segments"]:
            if node["oldId"] > max_id:
                max_id = node["oldId"]

            segment["to"] += id_offset
            segment["from"] += id_offset
            segment["oldId"] += id_offset
            segment["name"] = f"Segment {segment['oldId']}"
            segments.append(segment)

        id_offset += max_id + 1

    output["pathnodes"] = nodes
    output["segments"] = segments
    output["endNode"] = last_end_node

    print(json.dumps(output))

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
